@@ -15,10 +15,11 @@ def main() -> int:
         return 0
 
     if len(sys.argv) < 2:
-        print("Usage: hook_monitor.py <session_id> [event_name]", file=sys.stderr)
+        print("Usage: hook_monitor.py <session_id> [source_path]", file=sys.stderr)
         return 1
 
     session_id = sys.argv[1]
+    source_path = sys.argv[2] if len(sys.argv) > 2 else None
 
     base = os.getenv("CLAUDE_MONITOR_BASE", "http://127.0.0.1:8081")
 
@@ -39,6 +40,7 @@ def main() -> int:
         "event": payload["hook_event_name"],
         "receivedAt": payload.get("timestamp") or payload.get("time"),
         "payload": payload,
+        "source_path": source_path,
     }
 
     # Fire-and-forget POST (don't block Claude if monitor is unreachable)
